import pyant


def log_dbg(fmt, *args):
    msg = fmt % args
    pyant.DLOG(msg)


def log_inf(fmt, *args):
    msg = fmt % args
    pyant.ILOG(msg)


def log_wrn(fmt, *args):
    msg = fmt % args
    pyant.WLOG(msg)


def log_err(fmt, *args):
    msg = fmt % args
    pyant.ELOG(msg)


def log_fat(fmt, *args):
    msg = fmt % args
    pyant.FLOG(msg)



import json

try:
    from google.protobuf import json_format

    SUPPORT_PY_PROTOBUF = True
except Exception as e:
    SUPPORT_PY_PROTOBUF = False

import pyant


def call(service_name, method, data, op=pyant.Option.default_instance(), ep=pyant.Endpoint.default_instance()):
    if isinstance(data, str):
        msg_json = data
    elif isinstance(data, dict):
        msg_json = json.dumps(data)
    elif SUPPORT_PY_PROTOBUF and isinstance(data, google.protobuf.message.Message):
        msg_json = json_format.MessageToJson(
            data, preserving_proto_field_name=True, use_integers_for_enums=True)
    else:
        return -1, 'not supported data type'

    ret, msg = pyant.json_call_wait(service_name, method, msg_json, op, ep)
    if 0 == ret:
        msg = json.loads(msg)
    return ret, msg


def call_mf(service_name, method, data, op=pyant.Option.default_instance(), ep=pyant.Endpoint.default_instance()):
    if isinstance(data, str):
        msg_json = data
    elif isinstance(data, dict):
        msg_json = json.dumps(data)
    elif SUPPORT_PY_PROTOBUF and isinstance(data, google.protobuf.message.Message):
        msg_json = json_format.MessageToJson(
            data, preserving_proto_field_name=True, use_integers_for_enums=True)
    else:
        return -1, 'not supported data type'

    ret, msg = pyant.json_call_mf_wait(service_name, method, msg_json, op, ep)
    if ret == 0:
        for i in range(len(msg)):
            msg[i] = json.loads(msg[i])
    return ret, msg


def async_call(service_name, method, data, op=pyant.Option.default_instance(), ep=pyant.Endpoint.default_instance()):
    if isinstance(data, str):
        msg_json = data
    elif isinstance(data, dict):
        msg_json = json.dumps(data)
    elif SUPPORT_PY_PROTOBUF and isinstance(data, google.protobuf.message.Message):
        msg_json = json_format.MessageToJson(
            data, preserving_proto_field_name=True, use_integers_for_enums=True)
    else:
        raise Exception('not supported data type')

    return pyant.json_call(service_name, method, msg_json, op, ep)



from enum import Enum
import datetime

import ant
from rfsdk.protocol.condition.condition_futures_pb2 import ConditionInfo
from rfsdk.protocol.service_method import *
import rfsdk.protocol.condition.condition_req_helper as condition_req
from rfsdk.comm_utils import parse_exchange_id, pb2json
import rfsdk.protocol.trade.trade_req_helper as trade_req
from rfsdk.trade_client import CombOffsetFlagType


class _ConditionType(object):
    Take_Profit_And_Stop_Loss_Order = "0"
    Default_Condition_Order = "1"
    Take_Profit_Or_Stop_Loss_Order = "2"
    Guarantee_Order = "8"
    Dynamic_Stop_Loss_Order = "16"
    Stop_Loss_Open_Order = "32"


class ConditionOrderType(object):
    class Default_Condition_Order(object):
        Greater_Than_Time_Trigger = (
            _ConditionType.Default_Condition_Order, "f182(%s)")
        Equal_Time_Trigger = (
            _ConditionType.Default_Condition_Order, "f181(%s)")
        Greater_Than_Price_Trigger = (
            _ConditionType.Default_Condition_Order, "f108(%s)")
        Less_Than_Price_Trigger = (
            _ConditionType.Default_Condition_Order, "f109(%s)")
        Time_Price_comb_Greater_Than_Price_Trigger = (
            _ConditionType.Default_Condition_Order, "f1812(%s,%s,1)")
        Time_Price_comb_Less_Than_Price_Trigger = (
            _ConditionType.Default_Condition_Order, "f1812(%s,%s,0)")
        Protect_Price_Greater_Than_Time_Trigger = (
            _ConditionType.Default_Condition_Order, "f1819(%s,%s,%s)")
        Protect_Price_Equal_Time_Trigger = (
            _ConditionType.Default_Condition_Order, "f1829(%s,%s,%s)")
        Protect_Price_Greater_Than_Price_Trigger = (
            _ConditionType.Default_Condition_Order, "f1089(%s,%s,%s)")
        Protect_Price_Less_Than_Price_Trigger = (
            _ConditionType.Default_Condition_Order, "f1099(%s,%s,%s)")

    class Take_Profit_Or_Stop_Loss_Order(object):
        Greater_Than_Price_Trigger = (
            _ConditionType.Take_Profit_Or_Stop_Loss_Order, "f108(%s)")
        Less_Than_Price_Trigger = (
            _ConditionType.Take_Profit_Or_Stop_Loss_Order, "f109(%s)")

    class Guarantee_Order(object):
        Do_More_Trigger = (_ConditionType.Guarantee_Order, "f1242(%s,%s,%s,1)")
        Do_Less_Trigger = (_ConditionType.Guarantee_Order, "f1242(%s,%s,%s,0)")

    class Dynamic_Stop_Loss_Order(object):
        Do_More_Trigger = (
            _ConditionType.Dynamic_Stop_Loss_Order, "f1241(%s,%s,%s,1)")
        Do_Less_Trigger = (
            _ConditionType.Dynamic_Stop_Loss_Order, "f1241(%s,%s,%s,0)")


def make_signal_func(condition_order_type, condition_time=None, condition_price=None, price_diff=None,
                     order_price_type=None):
    condition_type = condition_order_type[0]
    if _ConditionType.Default_Condition_Order == condition_type:
        type_alias = ConditionOrderType.Default_Condition_Order
        if (type_alias.Equal_Time_Trigger == condition_order_type or
                type_alias.Greater_Than_Time_Trigger == condition_order_type):
            condition = condition_order_type[1] % str(condition_time)
        elif (type_alias.Greater_Than_Price_Trigger == condition_order_type or
              type_alias.Less_Than_Price_Trigger == condition_order_type):
            condition = condition_order_type[1] % str(condition_price)
        elif (type_alias.Time_Price_comb_Greater_Than_Price_Trigger == condition_order_type or
              type_alias.Time_Price_comb_Less_Than_Price_Trigger == condition_order_type):
            condition = condition_order_type[1] % (
                str(condition_time), str(condition_price))
        else:
            condition = condition_order_type[1] % (
                str(condition_time), str(order_price_type), str(price_diff))
    elif _ConditionType.Take_Profit_Or_Stop_Loss_Order == condition_type:
        condition = condition_order_type[1] % str(condition_price)
    elif (_ConditionType.Guarantee_Order == condition_type or
          _ConditionType.Dynamic_Stop_Loss_Order == condition_type):
        condition = condition_order_type[1] % (str(condition_price), str(
            price_diff), datetime.datetime.now().strftime("%Y%m%d%H%M%S"))
    else:
        ant.log_err("condition type error!")
        return None

    return condition


class ConditionClient(object):
    def __init__(self, inter_service, investor_id, investor_key):
        self._investor_id = investor_id
        self._investor_key = investor_key
        self._inter_service = inter_service
        self._rpc_call = self._inter_service.gateway_call
        self._rpc_call_mf = self._inter_service.gateway_call_mf

    def subscribe_changed_condition(self, func):
        self._inter_service.get_client().register_cb(TOPIC_CHANGED_CONDITION,
                                                     lambda pb_msg: pb2json(pb_msg, ConditionInfo(), func))
        self._inter_service.get_client().subscribe(TOPIC_CHANGED_CONDITION)

    def subscribe_trigger_condition(self, func):
        self._inter_service.get_client().register_cb(TOPIC_TRIGGER_CONDITION,
                                                     lambda pb_msg: pb2json(pb_msg, ConditionInfo(), func))
        self._inter_service.get_client().subscribe(TOPIC_TRIGGER_CONDITION)

    def unsubscribe_changed_condition(self):
        self._inter_service.get_client().unsubscribe(TOPIC_CHANGED_CONDITION)

    def unsubscribe_trigger_condition(self):
        self._inter_service.get_client().unsubscribe(TOPIC_TRIGGER_CONDITION)

    def condition_order_insert(self,
                               instrument_id,
                               volume_total_original,
                               valid_period_count,
                               condition_order_type=ConditionOrderType.Default_Condition_Order.Equal_Time_Trigger,
                               condition_time=None,
                               condition_price=None,
                               price_diff=None,
                               direction=trade_req.ActionType.ActionType_BUY,
                               comb_offset_flag=CombOffsetFlagType.OffsetFlagType_Open,
                               order_price_type=trade_req.OrderPriceType.OrderPriceType_LimitPrice,
                               condition_info=None,
                               limit_price=None,
                               init_flag=None,
                               broker_id=None,
                               interface_type=None,
                               source=None,
                               pre_order_no=None):
        exchange_id = parse_exchange_id(instrument_id)
        condition_type = condition_order_type[0]
        condition = make_signal_func(
            condition_order_type, condition_time, condition_price, price_diff, order_price_type)
        req = condition_req.make_insert_req(investor_key=self._investor_key,
                                            instrument_id=instrument_id,
                                            exchange_id=exchange_id,
                                            direction=direction,
                                            comb_offset_flag=comb_offset_flag,
                                            order_price_type=order_price_type,
                                            limit_price=limit_price,
                                            volume_total_original=volume_total_original,
                                            init_flag=init_flag,
                                            valid_period_count=valid_period_count,
                                            condition=condition,
                                            condition_type=condition_type,
                                            condition_info=condition_info,
                                            investor_id=self._investor_id,
                                            broker_id=broker_id,
                                            interface_type=interface_type,
                                            source=source,
                                            pre_order_no=pre_order_no)
        return self._rpc_call(SERVICE_CONDITION_FUTURE, METHOD_CONDITION_ORDER_INSERT, req)

    def condition_order_modify(self,
                               order_no,
                               volume_total_original,
                               valid_period_count,
                               condition_order_type,
                               condition_time=None,
                               condition_price=None,
                               price_diff=None,
                               comb_offset_flag=CombOffsetFlagType.OffsetFlagType_Open,
                               direction=trade_req.ActionType.ActionType_BUY,
                               order_price_type=trade_req.OrderPriceType.OrderPriceType_LimitPrice,
                               init_flag=None,
                               limit_price=None,
                               condition_info=None,
                               source=None,
                               pre_order_no=None,
                               modify_preorder_no=None):
        condition_type = condition_order_type[0]
        condition = make_signal_func(
            condition_order_type, condition_time, condition_price, price_diff, order_price_type)

        req = condition_req.make_modify_req(investor_key=self._investor_key,
                                            order_no=order_no,
                                            init_flag=init_flag,
                                            order_price_type=order_price_type,
                                            limit_price=limit_price,
                                            volume_total_original=volume_total_original,
                                            valid_period_count=valid_period_count,
                                            condition=condition,
                                            condition_type=condition_type,
                                            condition_info=condition_info,
                                            investor_id=self._investor_id,
                                            direction=direction,
                                            comb_offset_flag=comb_offset_flag,
                                            source=source,
                                            pre_order_no=pre_order_no,
                                            modify_preorder_no=modify_preorder_no)
        return self._rpc_call(SERVICE_CONDITION_FUTURE, METHOD_CONDITION_ORDER_MODIFY, req)

    def condition_order_pause(self,
                              order_no,
                              source=None):
        req = condition_req.make_pause_req(investor_key=self._investor_key,
                                           order_no=order_no,
                                           investor_id=self._investor_id,
                                           source=source)
        return self._rpc_call(SERVICE_CONDITION_FUTURE, METHOD_CONDITION_ORDER_PAUSE, req)

    def condition_order_activate(self,
                                 order_no,
                                 source=None):
        req = condition_req.make_activate_req(investor_key=self._investor_key,
                                              order_no=order_no,
                                              investor_id=self._investor_id,
                                              source=source)
        return self._rpc_call(SERVICE_CONDITION_FUTURE, METHOD_CONDITION_ORDER_ACTIVATE, req)

    def condition_order_cancel(self,
                               order_no,
                               source=None):
        req = condition_req.make_cancel_req(investor_key=self._investor_key,
                                            order_no=order_no,
                                            investor_id=self._investor_id,
                                            source=source)
        return self._rpc_call(SERVICE_CONDITION_FUTURE, METHOD_CONDITION_ORDER_CANCEL, req)

    def condition_order_delete(self,
                               order_no,
                               source=None):
        req = condition_req.make_delete_req(investor_key=self._investor_key,
                                            order_no=order_no,
                                            investor_id=self._investor_id,
                                            source=source)
        return self._rpc_call(SERVICE_CONDITION_FUTURE, METHOD_CONDITION_ORDER_DELETE, req)

    def condition_order_query(self,
                              order_no,
                              start_date=None,
                              end_date=None,
                              condition_type=None,
                              condition_status=None,
                              broker_id=None,
                              interface_type=None,
                              begin_time=None,
                              end_time=None):
        req = condition_req.make_query_req(investor_key=self._investor_key,
                                           order_no=order_no,
                                           start_date=start_date,
                                           end_date=end_date,
                                           condition_type=condition_type,
                                           condition_status=condition_status,
                                           investor_id=self._investor_id,
                                           broker_id=broker_id,
                                           interface_type=interface_type,
                                           begin_time=begin_time,
                                           end_time=end_time)
        return self._rpc_call(SERVICE_CONDITION_FUTURE, METHOD_CONDITION_ORDER_QUERY, req)

    def condition_order_multi_query(self,
                                    order_no=None,
                                    start_date=None,
                                    end_date=None,
                                    condition_type=None,
                                    condition_status=None,
                                    broker_id=None,
                                    interface_type=None,
                                    begin_time=None,
                                    end_time=None):
        req = condition_req.make_query_req(investor_key=self._investor_key,
                                           order_no=order_no,
                                           start_date=start_date,
                                           end_date=end_date,
                                           condition_type=condition_type,
                                           condition_status=condition_status,
                                           investor_id=self._investor_id,
                                           broker_id=broker_id,
                                           interface_type=interface_type,
                                           begin_time=begin_time,
                                           end_time=end_time)
        return self._rpc_call_mf(SERVICE_CONDITION_FUTURE, METHOD_CONDITION_ORDER_MULTIQUERY, req)



# -*- coding: utf-8 -*-

import inspect

from rfsdk.comm_utils import generate_req

from ant import encrypt_special


class InitFlag(object):
    InitFlag_Init = 0
    InitFlag_Pause = 1


class SettleFlag(object):
    SettleFlag_Undefined = 0
    SettleFlag_Init = 1
    SettleFlag_Settle = 2


# 条件单缓存信息存储
def make_condition_info(investor_key,
                        order_no,
                        instrument_id,
                        exchange_id,
                        direction,
                        comb_offset_flag,
                        order_price_type,
                        limit_price,
                        volume_total_original,
                        init_flag,
                        valid_period_count,
                        condition,
                        condition_type,
                        condition_info,
                        condition_status,
                        status_msg,
                        message,
                        insert_time,
                        activate_time,
                        modify_time,
                        end_time,
                        pause_time,
                        trigger_time,
                        trigger_hq_time,
                        trigger_tips,
                        trigger_entrust_price,
                        trigger_entrust_amount,
                        investor_id,
                        broker_id,
                        interface_type,
                        expire_date,
                        source,
                        pre_order_no,
                        trigger_price,
                        ):
    return generate_req(inspect.currentframe())


# 条件订单信息推送
def make_report(investor_key,
                order_no,
                instrument_id,
                exchange_id,
                direction,
                comb_offset_flag,
                order_price_type,
                limit_price,
                volume_total_original,
                init_flag,
                valid_period_count,
                condition,
                condition_type,
                condition_status,
                status_msg,
                message,
                insert_time,
                activate_time,
                modify_time,
                end_time,
                pause_time,
                trigger_time,
                trigger_hq_time,
                trigger_tips,
                trigger_entrust_price,
                trigger_entrust_amount,
                investor_id,
                broker_id,
                interface_type,
                expire_date,
                source,
                pre_order_no,
                trigger_price,
                ):
    return generate_req(inspect.currentframe())


# 创建条件单请求
def make_insert_req(investor_key,
                    instrument_id,
                    exchange_id,
                    direction,
                    comb_offset_flag,
                    order_price_type,
                    limit_price,
                    volume_total_original,
                    init_flag,
                    valid_period_count,
                    condition,
                    condition_type,
                    condition_info,
                    investor_id,
                    broker_id,
                    interface_type,
                    source,
                    pre_order_no,
                    ):
    return generate_req(inspect.currentframe())


# 条件单创建应答
def make_insert_rsp(result):
    return generate_req(inspect.currentframe())


# 条件单修改请求
def make_modify_req(investor_key,
                    order_no,
                    init_flag,
                    order_price_type,
                    limit_price,
                    volume_total_original,
                    valid_period_count,
                    condition,
                    condition_type,
                    condition_info,
                    investor_id,
                    direction,
                    comb_offset_flag,
                    source,
                    pre_order_no,
                    modify_preorder_no):
    return generate_req(inspect.currentframe())


# 条件单修改应答
def make_modify_rsp(result):
    return generate_req(inspect.currentframe())


# 条件单暂停请求
def make_pause_req(investor_key,
                   order_no,
                   investor_id,
                   source):
    return generate_req(inspect.currentframe())

    # 条件单暂停应答


def make_pause_rsp(result):
    return generate_req(inspect.currentframe())


# 条件单启动请求
def make_activate_req(investor_key,
                      order_no,
                      investor_id,
                      source):
    return generate_req(inspect.currentframe())


# 条件单启动应答
def make_activate_rsp(result):
    return generate_req(inspect.currentframe())


# 条件单删除请求
def make_delete_req(investor_key,
                    order_no,
                    investor_id,
                    source):
    return generate_req(inspect.currentframe())


# 条件单删除应答
def make_delete_rsp(result):
    return generate_req(inspect.currentframe())


# 条件单取消请求
def make_cancel_req(investor_key,
                    order_no,
                    investor_id,
                    source):
    return generate_req(inspect.currentframe())


# 条件单取消应答
def make_cancel_rsp(result):
    return generate_req(inspect.currentframe())


# 条件单查询/批量查询
def make_query_req(investor_key,
                   order_no,
                   start_date,
                   end_date,
                   condition_type,
                   condition_status,
                   investor_id,
                   broker_id,
                   interface_type,
                   begin_time,
                   end_time
                   ):
    return generate_req(inspect.currentframe())


# 条件单查询应答
def make_query_rsp(result):
    return generate_req(inspect.currentframe())


# 批量条件单查询应答
def make_multi_query_rsp(result):
    return generate_req(inspect.currentframe())


# 委托回报后推送委托与条件单的对应关系
def make_condition_push(investor_key,
                        condition_no,
                        instrument_id,
                        exchange_id,
                        trading_day,
                        order_sys_id,
                        direction):
    return generate_req(inspect.currentframe())


# 日初日终 请求
def make_condition_settle(type):
    return generate_req(inspect.currentframe())


# 日初日终 请求
def make_condition_settle_rsp(type):
    return generate_req(inspect.currentframe())


# 条件单实时触发价推送
def make_trigger_info(investor_key,
                      order_no,
                      trigger_price):
    return generate_req(inspect.currentframe())


# 查询合约信息
def make_instrument_info(instrument_id,
                         expire_date):
    return generate_req(inspect.currentframe())


# 查询合约返回
def make_instrument_info_list(result):
    return generate_req(inspect.currentframe())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: condition/nest_condition_futures.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from trade import trade_enum_pb2 as trade_dot_trade__enum__pb2
from trade import trade_pb2 as trade_dot_trade__pb2
from condition import condition_futures_pb2 as condition_dot_condition__futures__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='condition/nest_condition_futures.proto',
    package='nest_condition.futures',
    syntax='proto3',
    serialized_options=_b('\242\002\003NCF'),
    serialized_pb=_b(
        '\n&condition/nest_condition_futures.proto\x12\x16nest_condition.futures\x1a\x16trade/trade_enum.proto\x1a\x11trade/trade.proto\x1a!condition/condition_futures.proto\"\xc2\x03\n\rConditionItem\x12\x15\n\rinstrument_id\x18\x01 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x02 \x01(\t\x12(\n\tdirection\x18\x03 \x01(\x0e\x32\x15.trade.tag.ActionType\x12\x18\n\x10\x63omb_offset_flag\x18\x04 \x01(\t\x12\x33\n\x10order_price_type\x18\x05 \x01(\x0e\x32\x19.trade.tag.OrderPriceType\x12\x13\n\x0blimit_price\x18\x06 \x01(\x01\x12\x1d\n\x15volume_total_original\x18\x07 \x01(\r\x12.\n\tinit_flag\x18\x08 \x01(\x0e\x32\x1b.condition.futures.InitFlag\x12\x1a\n\x12valid_period_count\x18\t \x01(\r\x12\x11\n\tcondition\x18\n \x01(\t\x12\x16\n\x0e\x63ondition_type\x18\x0b \x01(\r\x12\x16\n\x0e\x63ondition_info\x18\x0c \x01(\t\x12\x16\n\x0estop_loss_type\x18\r \x01(\r\x12\x17\n\x0f\x62\x61se_price_type\x18\x0e \x01(\r\x12\x18\n\x10price_difference\x18\x0f \x01(\x01\"\xb8\x01\n\x11NestConditionInfo\x12%\n\x06source\x18\x01 \x01(\x0e\x32\x15.trade.tag.SourceType\x12<\n\tnest_type\x18\x02 \x01(\x0e\x32).nest_condition.futures.NestConditionType\x12>\n\x0f\x63ondition_items\x18\x03 \x03(\x0b\x32%.nest_condition.futures.ConditionItem\"\x95\x01\n\x12\x43onditionOrderItem\x12\x37\n\x14\x63ondition_order_info\x18\x01 \x01(\x0b\x32\x19.condition.futures.Report\x12\x46\n\x13nest_condition_info\x18\x02 \x01(\x0b\x32).nest_condition.futures.NestConditionInfo\"\x9c\x02\n\tInsertReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x13\n\x0binvestor_id\x18\x02 \x01(\t\x12\x11\n\tbroker_id\x18\x03 \x01(\t\x12,\n\x0einterface_type\x18\x04 \x01(\x0e\x32\x14.trade.InterfaceType\x12%\n\x06source\x18\x05 \x01(\x0e\x32\x15.trade.tag.SourceType\x12<\n\tnest_type\x18\x06 \x01(\x0e\x32).nest_condition.futures.NestConditionType\x12>\n\x0f\x63ondition_items\x18\x07 \x03(\x0b\x32%.nest_condition.futures.ConditionItem\"\x1d\n\tInsertRsp\x12\x10\n\x08order_no\x18\x01 \x01(\t\"\xca\x02\n\tModifyReq\x12\x10\n\x08order_no\x18\x01 \x01(\t\x12\x1a\n\x12\x63ondition_order_no\x18\x02 \x01(\t\x12\x14\n\x0cinvestor_key\x18\x03 \x01(\x04\x12\x13\n\x0binvestor_id\x18\x04 \x01(\t\x12\x11\n\tbroker_id\x18\x05 \x01(\t\x12,\n\x0einterface_type\x18\x06 \x01(\x0e\x32\x14.trade.InterfaceType\x12%\n\x06source\x18\x07 \x01(\x0e\x32\x15.trade.tag.SourceType\x12<\n\tnest_type\x18\x08 \x01(\x0e\x32).nest_condition.futures.NestConditionType\x12>\n\x0f\x63ondition_items\x18\t \x03(\x0b\x32%.nest_condition.futures.ConditionItem\"9\n\tModifyRsp\x12\x10\n\x08order_no\x18\x01 \x01(\t\x12\x1a\n\x12\x63ondition_order_no\x18\x02 \x01(\t\"\xa6\x02\n\x08QueryReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x12\n\nstart_date\x18\x03 \x01(\r\x12\x10\n\x08\x65nd_date\x18\x04 \x01(\r\x12\x16\n\x0e\x63ondition_type\x18\x05 \x01(\r\x12\x38\n\x10\x63ondition_status\x18\x06 \x01(\x0e\x32\x1e.trade.tag.ConditionStatusType\x12\x13\n\x0binvestor_id\x18\x07 \x01(\t\x12\x11\n\tbroker_id\x18\x08 \x01(\t\x12,\n\x0einterface_type\x18\t \x01(\x0e\x32\x14.trade.InterfaceType\x12\x12\n\nbegin_time\x18\n \x01(\t\x12\x10\n\x08\x65nd_time\x18\x0b \x01(\t\"G\n\x08QueryRsp\x12;\n\x07results\x18\x01 \x03(\x0b\x32*.nest_condition.futures.ConditionOrderItem\"\x93\x05\n\rConditionInfo\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x13\n\x0binvestor_id\x18\x02 \x01(\t\x12\x11\n\tbroker_id\x18\x03 \x01(\t\x12,\n\x0einterface_type\x18\x04 \x01(\x0e\x32\x14.trade.InterfaceType\x12%\n\x06source\x18\x05 \x01(\x0e\x32\x15.trade.tag.SourceType\x12<\n\tnest_type\x18\x06 \x01(\x0e\x32).nest_condition.futures.NestConditionType\x12\x15\n\rinstrument_id\x18\x07 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x08 \x01(\t\x12(\n\tdirection\x18\t \x01(\x0e\x32\x15.trade.tag.ActionType\x12\x18\n\x10\x63omb_offset_flag\x18\n \x01(\t\x12\x33\n\x10order_price_type\x18\x0b \x01(\x0e\x32\x19.trade.tag.OrderPriceType\x12\x13\n\x0blimit_price\x18\x0c \x01(\x01\x12\x1d\n\x15volume_total_original\x18\r \x01(\r\x12.\n\tinit_flag\x18\x0e \x01(\x0e\x32\x1b.condition.futures.InitFlag\x12\x1a\n\x12valid_period_count\x18\x0f \x01(\r\x12\x11\n\tcondition\x18\x10 \x01(\t\x12\x16\n\x0e\x63ondition_type\x18\x11 \x01(\r\x12\x16\n\x0e\x63ondition_info\x18\x12 \x01(\t\x12\x16\n\x0estop_loss_type\x18\x13 \x01(\r\x12\x17\n\x0f\x62\x61se_price_type\x18\x14 \x01(\r\x12\x18\n\x10price_difference\x18\x15 \x01(\x01\"\xc1\x03\n\x11NestConditionItem\x12\x10\n\x08order_no\x18\x01 \x01(\t\x12\x14\n\x0cinvestor_key\x18\x02 \x01(\x04\x12\x13\n\x0binvestor_id\x18\x03 \x01(\t\x12\x11\n\tbroker_id\x18\x04 \x01(\t\x12,\n\x0einterface_type\x18\x05 \x01(\x0e\x32\x14.trade.InterfaceType\x12%\n\x06source\x18\x06 \x01(\x0e\x32\x15.trade.tag.SourceType\x12<\n\tnest_type\x18\x07 \x01(\x0e\x32).nest_condition.futures.NestConditionType\x12\x16\n\x0e\x63ondition_size\x18\x08 \x01(\r\x12\x13\n\x0binsert_time\x18\t \x01(\t\x12;\n\x06status\x18\n \x01(\x0e\x32+.nest_condition.futures.NestConditionStatus\x12\x12\n\nstatus_msg\x18\x0b \x01(\x0c\x12\x13\n\x0bupdate_time\x18\x0c \x01(\t\x12\x19\n\x11\x66irst_trade_price\x18\r \x01(\x01\x12\x1b\n\x13\x65ntrust_rival_price\x18\x0e \x01(\x01*U\n\x11NestConditionType\x12\x1d\n\x19NestConditionType_Default\x10\x00\x12!\n\x1dNestConditionType_OpenAndStop\x10\x01*\xd3\x01\n\x13NestConditionStatus\x12\x1f\n\x1bNestConditionStatus_Default\x10\x00\x12(\n$NestConditionStatus_OpenOrderCreated\x10\x01\x12*\n&NestConditionStatus_OpenOrderEntrusted\x10\x02\x12(\n$NestConditionStatus_OpenOrderTrading\x10\x03\x12\x1b\n\x17NestConditionStatus_End\x10\x04\x42\x06\xa2\x02\x03NCFb\x06proto3')
    ,
    dependencies=[trade_dot_trade__enum__pb2.DESCRIPTOR, trade_dot_trade__pb2.DESCRIPTOR,
                  condition_dot_condition__futures__pb2.DESCRIPTOR, ])

_NESTCONDITIONTYPE = _descriptor.EnumDescriptor(
    name='NestConditionType',
    full_name='nest_condition.futures.NestConditionType',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name='NestConditionType_Default', index=0, number=0,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='NestConditionType_OpenAndStop', index=1, number=1,
            serialized_options=None,
            type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=3130,
    serialized_end=3215,
)
_sym_db.RegisterEnumDescriptor(_NESTCONDITIONTYPE)

NestConditionType = enum_type_wrapper.EnumTypeWrapper(_NESTCONDITIONTYPE)
_NESTCONDITIONSTATUS = _descriptor.EnumDescriptor(
    name='NestConditionStatus',
    full_name='nest_condition.futures.NestConditionStatus',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name='NestConditionStatus_Default', index=0, number=0,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='NestConditionStatus_OpenOrderCreated', index=1, number=1,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='NestConditionStatus_OpenOrderEntrusted', index=2, number=2,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='NestConditionStatus_OpenOrderTrading', index=3, number=3,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='NestConditionStatus_End', index=4, number=4,
            serialized_options=None,
            type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=3218,
    serialized_end=3429,
)
_sym_db.RegisterEnumDescriptor(_NESTCONDITIONSTATUS)

NestConditionStatus = enum_type_wrapper.EnumTypeWrapper(_NESTCONDITIONSTATUS)
NestConditionType_Default = 0
NestConditionType_OpenAndStop = 1
NestConditionStatus_Default = 0
NestConditionStatus_OpenOrderCreated = 1
NestConditionStatus_OpenOrderEntrusted = 2
NestConditionStatus_OpenOrderTrading = 3
NestConditionStatus_End = 4

_CONDITIONITEM = _descriptor.Descriptor(
    name='ConditionItem',
    full_name='nest_condition.futures.ConditionItem',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='instrument_id', full_name='nest_condition.futures.ConditionItem.instrument_id', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='exchange_id', full_name='nest_condition.futures.ConditionItem.exchange_id', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='direction', full_name='nest_condition.futures.ConditionItem.direction', index=2,
            number=3, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='comb_offset_flag', full_name='nest_condition.futures.ConditionItem.comb_offset_flag', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='order_price_type', full_name='nest_condition.futures.ConditionItem.order_price_type', index=4,
            number=5, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='limit_price', full_name='nest_condition.futures.ConditionItem.limit_price', index=5,
            number=6, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='volume_total_original', full_name='nest_condition.futures.ConditionItem.volume_total_original',
            index=6,
            number=7, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='init_flag', full_name='nest_condition.futures.ConditionItem.init_flag', index=7,
            number=8, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='valid_period_count', full_name='nest_condition.futures.ConditionItem.valid_period_count', index=8,
            number=9, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition', full_name='nest_condition.futures.ConditionItem.condition', index=9,
            number=10, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_type', full_name='nest_condition.futures.ConditionItem.condition_type', index=10,
            number=11, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_info', full_name='nest_condition.futures.ConditionItem.condition_info', index=11,
            number=12, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='stop_loss_type', full_name='nest_condition.futures.ConditionItem.stop_loss_type', index=12,
            number=13, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='base_price_type', full_name='nest_condition.futures.ConditionItem.base_price_type', index=13,
            number=14, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='price_difference', full_name='nest_condition.futures.ConditionItem.price_difference', index=14,
            number=15, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=145,
    serialized_end=595,
)

_NESTCONDITIONINFO = _descriptor.Descriptor(
    name='NestConditionInfo',
    full_name='nest_condition.futures.NestConditionInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='source', full_name='nest_condition.futures.NestConditionInfo.source', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='nest_type', full_name='nest_condition.futures.NestConditionInfo.nest_type', index=1,
            number=2, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_items', full_name='nest_condition.futures.NestConditionInfo.condition_items', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=598,
    serialized_end=782,
)

_CONDITIONORDERITEM = _descriptor.Descriptor(
    name='ConditionOrderItem',
    full_name='nest_condition.futures.ConditionOrderItem',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='condition_order_info', full_name='nest_condition.futures.ConditionOrderItem.condition_order_info',
            index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='nest_condition_info', full_name='nest_condition.futures.ConditionOrderItem.nest_condition_info',
            index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=785,
    serialized_end=934,
)

_INSERTREQ = _descriptor.Descriptor(
    name='InsertReq',
    full_name='nest_condition.futures.InsertReq',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='nest_condition.futures.InsertReq.investor_key', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_id', full_name='nest_condition.futures.InsertReq.investor_id', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='broker_id', full_name='nest_condition.futures.InsertReq.broker_id', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='interface_type', full_name='nest_condition.futures.InsertReq.interface_type', index=3,
            number=4, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='source', full_name='nest_condition.futures.InsertReq.source', index=4,
            number=5, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='nest_type', full_name='nest_condition.futures.InsertReq.nest_type', index=5,
            number=6, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_items', full_name='nest_condition.futures.InsertReq.condition_items', index=6,
            number=7, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=937,
    serialized_end=1221,
)

_INSERTRSP = _descriptor.Descriptor(
    name='InsertRsp',
    full_name='nest_condition.futures.InsertRsp',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='order_no', full_name='nest_condition.futures.InsertRsp.order_no', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1223,
    serialized_end=1252,
)

_MODIFYREQ = _descriptor.Descriptor(
    name='ModifyReq',
    full_name='nest_condition.futures.ModifyReq',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='order_no', full_name='nest_condition.futures.ModifyReq.order_no', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_order_no', full_name='nest_condition.futures.ModifyReq.condition_order_no', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='nest_condition.futures.ModifyReq.investor_key', index=2,
            number=3, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_id', full_name='nest_condition.futures.ModifyReq.investor_id', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='broker_id', full_name='nest_condition.futures.ModifyReq.broker_id', index=4,
            number=5, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='interface_type', full_name='nest_condition.futures.ModifyReq.interface_type', index=5,
            number=6, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='source', full_name='nest_condition.futures.ModifyReq.source', index=6,
            number=7, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='nest_type', full_name='nest_condition.futures.ModifyReq.nest_type', index=7,
            number=8, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_items', full_name='nest_condition.futures.ModifyReq.condition_items', index=8,
            number=9, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1255,
    serialized_end=1585,
)

_MODIFYRSP = _descriptor.Descriptor(
    name='ModifyRsp',
    full_name='nest_condition.futures.ModifyRsp',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='order_no', full_name='nest_condition.futures.ModifyRsp.order_no', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_order_no', full_name='nest_condition.futures.ModifyRsp.condition_order_no', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1587,
    serialized_end=1644,
)

_QUERYREQ = _descriptor.Descriptor(
    name='QueryReq',
    full_name='nest_condition.futures.QueryReq',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='nest_condition.futures.QueryReq.investor_key', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='order_no', full_name='nest_condition.futures.QueryReq.order_no', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='start_date', full_name='nest_condition.futures.QueryReq.start_date', index=2,
            number=3, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='end_date', full_name='nest_condition.futures.QueryReq.end_date', index=3,
            number=4, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_type', full_name='nest_condition.futures.QueryReq.condition_type', index=4,
            number=5, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_status', full_name='nest_condition.futures.QueryReq.condition_status', index=5,
            number=6, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_id', full_name='nest_condition.futures.QueryReq.investor_id', index=6,
            number=7, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='broker_id', full_name='nest_condition.futures.QueryReq.broker_id', index=7,
            number=8, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='interface_type', full_name='nest_condition.futures.QueryReq.interface_type', index=8,
            number=9, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='begin_time', full_name='nest_condition.futures.QueryReq.begin_time', index=9,
            number=10, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='end_time', full_name='nest_condition.futures.QueryReq.end_time', index=10,
            number=11, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1647,
    serialized_end=1941,
)

_QUERYRSP = _descriptor.Descriptor(
    name='QueryRsp',
    full_name='nest_condition.futures.QueryRsp',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='results', full_name='nest_condition.futures.QueryRsp.results', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1943,
    serialized_end=2014,
)

_CONDITIONINFO = _descriptor.Descriptor(
    name='ConditionInfo',
    full_name='nest_condition.futures.ConditionInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='nest_condition.futures.ConditionInfo.investor_key', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_id', full_name='nest_condition.futures.ConditionInfo.investor_id', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='broker_id', full_name='nest_condition.futures.ConditionInfo.broker_id', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='interface_type', full_name='nest_condition.futures.ConditionInfo.interface_type', index=3,
            number=4, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='source', full_name='nest_condition.futures.ConditionInfo.source', index=4,
            number=5, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='nest_type', full_name='nest_condition.futures.ConditionInfo.nest_type', index=5,
            number=6, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='instrument_id', full_name='nest_condition.futures.ConditionInfo.instrument_id', index=6,
            number=7, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='exchange_id', full_name='nest_condition.futures.ConditionInfo.exchange_id', index=7,
            number=8, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='direction', full_name='nest_condition.futures.ConditionInfo.direction', index=8,
            number=9, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='comb_offset_flag', full_name='nest_condition.futures.ConditionInfo.comb_offset_flag', index=9,
            number=10, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='order_price_type', full_name='nest_condition.futures.ConditionInfo.order_price_type', index=10,
            number=11, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='limit_price', full_name='nest_condition.futures.ConditionInfo.limit_price', index=11,
            number=12, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='volume_total_original', full_name='nest_condition.futures.ConditionInfo.volume_total_original',
            index=12,
            number=13, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='init_flag', full_name='nest_condition.futures.ConditionInfo.init_flag', index=13,
            number=14, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='valid_period_count', full_name='nest_condition.futures.ConditionInfo.valid_period_count', index=14,
            number=15, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition', full_name='nest_condition.futures.ConditionInfo.condition', index=15,
            number=16, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_type', full_name='nest_condition.futures.ConditionInfo.condition_type', index=16,
            number=17, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_info', full_name='nest_condition.futures.ConditionInfo.condition_info', index=17,
            number=18, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='stop_loss_type', full_name='nest_condition.futures.ConditionInfo.stop_loss_type', index=18,
            number=19, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='base_price_type', full_name='nest_condition.futures.ConditionInfo.base_price_type', index=19,
            number=20, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='price_difference', full_name='nest_condition.futures.ConditionInfo.price_difference', index=20,
            number=21, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2017,
    serialized_end=2676,
)

_NESTCONDITIONITEM = _descriptor.Descriptor(
    name='NestConditionItem',
    full_name='nest_condition.futures.NestConditionItem',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='order_no', full_name='nest_condition.futures.NestConditionItem.order_no', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='nest_condition.futures.NestConditionItem.investor_key', index=1,
            number=2, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_id', full_name='nest_condition.futures.NestConditionItem.investor_id', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='broker_id', full_name='nest_condition.futures.NestConditionItem.broker_id', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='interface_type', full_name='nest_condition.futures.NestConditionItem.interface_type', index=4,
            number=5, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='source', full_name='nest_condition.futures.NestConditionItem.source', index=5,
            number=6, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='nest_type', full_name='nest_condition.futures.NestConditionItem.nest_type', index=6,
            number=7, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_size', full_name='nest_condition.futures.NestConditionItem.condition_size', index=7,
            number=8, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='insert_time', full_name='nest_condition.futures.NestConditionItem.insert_time', index=8,
            number=9, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='status', full_name='nest_condition.futures.NestConditionItem.status', index=9,
            number=10, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='status_msg', full_name='nest_condition.futures.NestConditionItem.status_msg', index=10,
            number=11, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='update_time', full_name='nest_condition.futures.NestConditionItem.update_time', index=11,
            number=12, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='first_trade_price', full_name='nest_condition.futures.NestConditionItem.first_trade_price', index=12,
            number=13, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='entrust_rival_price', full_name='nest_condition.futures.NestConditionItem.entrust_rival_price',
            index=13,
            number=14, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2679,
    serialized_end=3128,
)

_CONDITIONITEM.fields_by_name['direction'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_CONDITIONITEM.fields_by_name['order_price_type'].enum_type = trade_dot_trade__enum__pb2._ORDERPRICETYPE
_CONDITIONITEM.fields_by_name['init_flag'].enum_type = condition_dot_condition__futures__pb2._INITFLAG
_NESTCONDITIONINFO.fields_by_name['source'].enum_type = trade_dot_trade__enum__pb2._SOURCETYPE
_NESTCONDITIONINFO.fields_by_name['nest_type'].enum_type = _NESTCONDITIONTYPE
_NESTCONDITIONINFO.fields_by_name['condition_items'].message_type = _CONDITIONITEM
_CONDITIONORDERITEM.fields_by_name['condition_order_info'].message_type = condition_dot_condition__futures__pb2._REPORT
_CONDITIONORDERITEM.fields_by_name['nest_condition_info'].message_type = _NESTCONDITIONINFO
_INSERTREQ.fields_by_name['interface_type'].enum_type = trade_dot_trade__pb2._INTERFACETYPE
_INSERTREQ.fields_by_name['source'].enum_type = trade_dot_trade__enum__pb2._SOURCETYPE
_INSERTREQ.fields_by_name['nest_type'].enum_type = _NESTCONDITIONTYPE
_INSERTREQ.fields_by_name['condition_items'].message_type = _CONDITIONITEM
_MODIFYREQ.fields_by_name['interface_type'].enum_type = trade_dot_trade__pb2._INTERFACETYPE
_MODIFYREQ.fields_by_name['source'].enum_type = trade_dot_trade__enum__pb2._SOURCETYPE
_MODIFYREQ.fields_by_name['nest_type'].enum_type = _NESTCONDITIONTYPE
_MODIFYREQ.fields_by_name['condition_items'].message_type = _CONDITIONITEM
_QUERYREQ.fields_by_name['condition_status'].enum_type = trade_dot_trade__enum__pb2._CONDITIONSTATUSTYPE
_QUERYREQ.fields_by_name['interface_type'].enum_type = trade_dot_trade__pb2._INTERFACETYPE
_QUERYRSP.fields_by_name['results'].message_type = _CONDITIONORDERITEM
_CONDITIONINFO.fields_by_name['interface_type'].enum_type = trade_dot_trade__pb2._INTERFACETYPE
_CONDITIONINFO.fields_by_name['source'].enum_type = trade_dot_trade__enum__pb2._SOURCETYPE
_CONDITIONINFO.fields_by_name['nest_type'].enum_type = _NESTCONDITIONTYPE
_CONDITIONINFO.fields_by_name['direction'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_CONDITIONINFO.fields_by_name['order_price_type'].enum_type = trade_dot_trade__enum__pb2._ORDERPRICETYPE
_CONDITIONINFO.fields_by_name['init_flag'].enum_type = condition_dot_condition__futures__pb2._INITFLAG
_NESTCONDITIONITEM.fields_by_name['interface_type'].enum_type = trade_dot_trade__pb2._INTERFACETYPE
_NESTCONDITIONITEM.fields_by_name['source'].enum_type = trade_dot_trade__enum__pb2._SOURCETYPE
_NESTCONDITIONITEM.fields_by_name['nest_type'].enum_type = _NESTCONDITIONTYPE
_NESTCONDITIONITEM.fields_by_name['status'].enum_type = _NESTCONDITIONSTATUS
DESCRIPTOR.message_types_by_name['ConditionItem'] = _CONDITIONITEM
DESCRIPTOR.message_types_by_name['NestConditionInfo'] = _NESTCONDITIONINFO
DESCRIPTOR.message_types_by_name['ConditionOrderItem'] = _CONDITIONORDERITEM
DESCRIPTOR.message_types_by_name['InsertReq'] = _INSERTREQ
DESCRIPTOR.message_types_by_name['InsertRsp'] = _INSERTRSP
DESCRIPTOR.message_types_by_name['ModifyReq'] = _MODIFYREQ
DESCRIPTOR.message_types_by_name['ModifyRsp'] = _MODIFYRSP
DESCRIPTOR.message_types_by_name['QueryReq'] = _QUERYREQ
DESCRIPTOR.message_types_by_name['QueryRsp'] = _QUERYRSP
DESCRIPTOR.message_types_by_name['ConditionInfo'] = _CONDITIONINFO
DESCRIPTOR.message_types_by_name['NestConditionItem'] = _NESTCONDITIONITEM
DESCRIPTOR.enum_types_by_name['NestConditionType'] = _NESTCONDITIONTYPE
DESCRIPTOR.enum_types_by_name['NestConditionStatus'] = _NESTCONDITIONSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConditionItem = _reflection.GeneratedProtocolMessageType('ConditionItem', (_message.Message,), {
    'DESCRIPTOR': _CONDITIONITEM,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.ConditionItem)
})
_sym_db.RegisterMessage(ConditionItem)

NestConditionInfo = _reflection.GeneratedProtocolMessageType('NestConditionInfo', (_message.Message,), {
    'DESCRIPTOR': _NESTCONDITIONINFO,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.NestConditionInfo)
})
_sym_db.RegisterMessage(NestConditionInfo)

ConditionOrderItem = _reflection.GeneratedProtocolMessageType('ConditionOrderItem', (_message.Message,), {
    'DESCRIPTOR': _CONDITIONORDERITEM,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.ConditionOrderItem)
})
_sym_db.RegisterMessage(ConditionOrderItem)

InsertReq = _reflection.GeneratedProtocolMessageType('InsertReq', (_message.Message,), {
    'DESCRIPTOR': _INSERTREQ,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.InsertReq)
})
_sym_db.RegisterMessage(InsertReq)

InsertRsp = _reflection.GeneratedProtocolMessageType('InsertRsp', (_message.Message,), {
    'DESCRIPTOR': _INSERTRSP,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.InsertRsp)
})
_sym_db.RegisterMessage(InsertRsp)

ModifyReq = _reflection.GeneratedProtocolMessageType('ModifyReq', (_message.Message,), {
    'DESCRIPTOR': _MODIFYREQ,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.ModifyReq)
})
_sym_db.RegisterMessage(ModifyReq)

ModifyRsp = _reflection.GeneratedProtocolMessageType('ModifyRsp', (_message.Message,), {
    'DESCRIPTOR': _MODIFYRSP,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.ModifyRsp)
})
_sym_db.RegisterMessage(ModifyRsp)

QueryReq = _reflection.GeneratedProtocolMessageType('QueryReq', (_message.Message,), {
    'DESCRIPTOR': _QUERYREQ,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.QueryReq)
})
_sym_db.RegisterMessage(QueryReq)

QueryRsp = _reflection.GeneratedProtocolMessageType('QueryRsp', (_message.Message,), {
    'DESCRIPTOR': _QUERYRSP,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.QueryRsp)
})
_sym_db.RegisterMessage(QueryRsp)

ConditionInfo = _reflection.GeneratedProtocolMessageType('ConditionInfo', (_message.Message,), {
    'DESCRIPTOR': _CONDITIONINFO,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.ConditionInfo)
})
_sym_db.RegisterMessage(ConditionInfo)

NestConditionItem = _reflection.GeneratedProtocolMessageType('NestConditionItem', (_message.Message,), {
    'DESCRIPTOR': _NESTCONDITIONITEM,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.NestConditionItem)
})
_sym_db.RegisterMessage(NestConditionItem)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# pyant
import sys
import os
ant_root_path = os.path.dirname(os.path.abspath(__file__))
if ant_root_path not in sys.path:
    sys.path.append(ant_root_path)

__version__ = '0.4.4'

from pyant import *
from .rpc_call_helper import call, async_call, call_mf
from .logger import log_dbg, log_inf, log_wrn, log_err, log_fat



# -*- coding: utf-8 -*-
import os
import ant
import uuid
from rfsdk.protocol.service_method import *


class Gateway(object):
    SERVER_NAME = 'rfsdk_gateway'

    def __init__(self, ip, port, conf=ant.GlobalConf()):
        self._ip = ip
        self._port = port
        self._client = None
        self._server = None
        self._option = ant.Option()
        self._protocol_head = None
        self._service_name =str(uuid.uuid4())[0:6]
        self._use_verbose_log = True
        self._is_console_log = True
        self._log_dir = os.path.join(os.path.dirname(os.getcwd()) + '/log')

    def connect(self):
        gateway_auth = ant.GatewayAuthenticator()
        ant.init_gateway_auth(gateway_auth, self._ip)

        self._client = ant.Client(name=self._service_name, need_ns=False, auth=gateway_auth)
        self._client.set_used_verbose_log(self._use_verbose_log)

        ep = ant.Endpoint()
        ep.set_communication_type(ant.CommunicationType.kCommunicationTcp)
        ep.set_ip(self._ip)
        ep.set_port(self._port)
        ep.set_protocol(ant.ProtocolType.kProtocolGateway)
        ep.set_required_auth(True)

        self._client.append_endpoint(ep)

        self._client.set_on_create_channel(
            lambda conn: conn.get_codec().set_protocol_head(self._protocol_head))

        if self._server is None:
            self._server = ant.Server.instance(Gateway.SERVER_NAME)
            self._server.set_log_dir(self._is_console_log, self._log_dir)
            self._server.start(conf=ant.GlobalConf())

        self._server.add_client(self._client)

        if self._client.sync_auth():
            return True
        else:
            ant.log_err('gateway auth failed!')
            return False

    def wait(self):
        self._server.wait()

    def set_log_dir(self, is_console_log, log_dir):
        self._is_console_log = is_console_log
        if log_dir is not None:
            self._log_dir = log_dir

    def set_protocol_head(self, protocol_head):
        self._protocol_head = protocol_head

    def set_default_service_name(self, service_name):
        self._service_name = service_name

    def set_used_verbose_log(self, need_log):
        self._use_verbose_log = need_log

    def get_server(self):
        return self._server

    def get_client(self):
        return self._client

    def gateway_call(self, service, method, req):
        self._option.set_forward_service_name(service)
        ret, rsp = ant.call(self._service_name, method, req, self._option)
        if method is METHOD_ACCOUNT_LOGIN and ret == 0:
            investor_key = str(rsp['login']['investor_key'])
            channel_key = investor_key[0:-2]
            interface_type = int(investor_key[1:3])
            service_type = 2 ** interface_type
            self._option.set_channel_key(channel_key)
            self._option.set_service_type(service_type)

        return ret, rsp

    def gateway_call_mf(self, service, method, req):
        self._option.set_forward_service_name(service)
        return ant.call_mf(self._service_name, method, req, self._option)



import setuptools

with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name="rfsdk",
    version="0.4.4",
    author="loufu",
    author_email="loufu.2004@163.com",
    description="No description.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
	include_package_data=True,
    install_requires=[
        'protobuf'
    ],
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Operating System :: Microsoft :: Windows :: Windows 7",
    ],
)


# -*- coding: utf-8 -*-
from rfsdk.gateway import Gateway
from rfsdk.protocol.quote.quote_pb2 import NotificationTick
from rfsdk.protocol.service_method import *
import rfsdk.protocol.quote.quote_req_helper as quote_req
from rfsdk.comm_utils import parse_exchange_id, pb2json


class QuoteClient(object):

    def __init__(self, inter_service):
        self._rpc_call = None
        self._inter_service = None
        if isinstance(inter_service, Gateway):  # 暂时只支持网关接入
            self._inter_service = inter_service
            self._inter_service.set_default_service_name(SERVICE_MARKETDATA)
            self._inter_service.set_protocol_head(chr(0x0c))
            self._inter_service.set_used_verbose_log(False)
            self._rpc_call = self._inter_service.gateway_call
        else:
            raise Exception('not supported service type')

    def start(self):
        return self._inter_service.connect()

    def query_last_quote(self,
                         instrument_id,
                         instrument_type=quote_req.InstrumentType.InstrumentType_Future):
        '''
        查询最新行情tick
        Args:
            instrument_id: 合约id
            instrument_type: 合约类型

        Returns:tick Rsp

        '''
        exchange_id = parse_exchange_id(instrument_id)
        req = quote_req.make_query_last_quote_req(exchange_id=exchange_id, instrument_id=instrument_id,
                                                  instrument_type=instrument_type)
        return self._rpc_call(SERVICE_QUOTA, METHOD_MD_QUERY_LAST_QUOTE, req)

    def query_batch_bar_data(self,
                             instrument_id,
                             bar_type=quote_req.BarType.BarType_Min,
                             start_time=None,
                             end_time=None,
                             data_type='6,7,8,9,11',
                             formula=None,
                             ):
        '''
        查询K线
        Args:
            instrument_id: 合约
            date:时间格式"20210909"(日)，"20210909"
            instrument_type: 合约类型
            bar_type: K线类型（分钟、日、月等）
            start_time: 查询其起始时间 时间格式"20210909"(日)
            end_time: 查询终止时间
            data_type:数据项 PRECLOSE='6',OPEN='7',HIGH='8',LOW='9',CLOSE='11'
            formula:指标公式

        Returns:BarData Rsp

        '''
        exchange_id = parse_exchange_id(instrument_id)
        instrument_id = instrument_id + '.' + exchange_id
        req = quote_req.make_query_bar_data_req(instrument_id=instrument_id,
                                                bar_type=bar_type,
                                                start_time=start_time,
                                                end_time=end_time, formula=formula)
        return self._rpc_call(SERVICE_QUOTA, METHOD_MD_QUERY_BATCH_BAR_DATA, req)

    def subscribe_quote(self,
                        func,
                        instrument_id):
        '''
        订阅某合约行情tick
        Args:
            func:回调函数
            instrument_id: 合约id

        Returns:tick Rsp

        '''
        topic = TOPIC_QUOTE_TICK_Futures + '.' + instrument_id
        self._inter_service.get_client().register_cb(topic, lambda pb_msg: pb2json(pb_msg, NotificationTick(), func))
        self._inter_service.get_client().subscribe(topic)

    def unsubscribe_quote(self,
                          instrument_id):
        '''
        取消订阅某合约行情tick
        Args:
            instrument_id: 合约id
        '''
        topic = TOPIC_QUOTE_TICK_Futures + '.' + instrument_id
        self._inter_service.get_client().unsubscribe(topic)



# -*- coding: utf-8 -*-
import os
import inspect
import re
import json

from google.protobuf import json_format
from rfsdk.protocol.trade.trade_pb2 import InterfaceType

with open(os.path.join(os.path.dirname(os.path.abspath(__file__)), 'conf/instrument.json'), 'r') as f:
    _instrument_list = json.load(f)

with open(os.path.join(os.path.dirname(os.path.abspath(__file__)), 'conf/station.json'), 'r') as f:
    _station_list = json.load(f)

_platform_type_map = dict()
_platform_type_map[InterfaceType.SELF] = 'SELF'  # 自返回
_platform_type_map[InterfaceType.QUICK] = 'QUICK'  # 快速柜台
_platform_type_map[InterfaceType.QUANTS] = 'QUANTS'  # 量化插件
_platform_type_map[InterfaceType.XTP] = 'XTP'  # xtp
_platform_type_map[InterfaceType.CTP] = 'CTP'  # ctp
_platform_type_map[InterfaceType.CTP_SE] = 'CTP_SE'  # ctp 穿透式
_platform_type_map[InterfaceType.KSFT] = 'KSFT'  # 金仕达
_platform_type_map[InterfaceType.UFX] = 'UFX'  # ufx
_platform_type_map[InterfaceType.CTP_MINI] = 'CTP_MINI'  # ctpmini
_platform_type_map[InterfaceType.FEMAS] = 'FEMAS'  # 飞马
_platform_type_map[InterfaceType.SGIT] = 'SGIT'  # 飞鼠
_platform_type_map[InterfaceType.APEX] = 'APEX'  # 顶点
_platform_type_map[InterfaceType.SIMULATE] = 'SIMULATE'  # 模拟柜台
_platform_type_map[InterfaceType.MOCK] = 'MOCK'  # 模拟期货自返回


def generate_req(frame):
    args, _, _, values = inspect.getargvalues(frame)
    req = dict()
    for arg_name in args:
        value = values[arg_name]
        if value is not None:
            req[arg_name] = value

    return req


def pb2json(pb_msg, msg_obj, func):
    msg_obj.ParseFromString(pb_msg)
    json_msg = json_format.MessageToJson(msg_obj, preserving_proto_field_name=True, use_integers_for_enums=True)
    func(json_msg)


def parse_exchange_id(instrument_id):
    ret = re.findall(r'^[a-zA-Z]+', instrument_id)
    instrument_code = ret[0].lower()
    for item in _instrument_list:
        if instrument_code in _instrument_list[item]:
            return item
    else:
        raise Exception(u'非法的合约品种')


def parse_broker_info(broker_type, interface_type):
    try:
        platform_type = _platform_type_map[interface_type]
        return _station_list[broker_type]['qsid'], _station_list[broker_type]['wt_info'][platform_type]
    except Exception as e:
        raise Exception(u'请选择支持的期商及柜台')



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='common.proto',
    package='common',
    syntax='proto3',
    serialized_options=_b('\242\002\003COM'),
    serialized_pb=_b(
        '\n\x0c\x63ommon.proto\x12\x06\x63ommon\"&\n\x05\x45rror\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\x0c\")\n\x03Log\x12\x11\n\tlog_level\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\x0c\x42\x06\xa2\x02\x03\x43OMb\x06proto3')
)

_ERROR = _descriptor.Descriptor(
    name='Error',
    full_name='common.Error',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='common.Error.code', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='message', full_name='common.Error.message', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=24,
    serialized_end=62,
)

_LOG = _descriptor.Descriptor(
    name='Log',
    full_name='common.Log',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='log_level', full_name='common.Log.log_level', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='message', full_name='common.Log.message', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=64,
    serialized_end=105,
)

DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.message_types_by_name['Log'] = _LOG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
    'DESCRIPTOR': _ERROR,
    '__module__': 'common_pb2'
    # @@protoc_insertion_point(class_scope:common.Error)
})
_sym_db.RegisterMessage(Error)

Log = _reflection.GeneratedProtocolMessageType('Log', (_message.Message,), {
    'DESCRIPTOR': _LOG,
    '__module__': 'common_pb2'
    # @@protoc_insertion_point(class_scope:common.Log)
})
_sym_db.RegisterMessage(Log)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
import ant

from rfsdk.gateway import Gateway
from rfsdk.protocol.trade.trade_futures_pb2 import OrderInfo
from rfsdk.protocol.trade.trade_futures_pb2 import TradeReportInfo
from rfsdk.protocol.service_method import *
import rfsdk.protocol.account.account_req_helper as account_req
import rfsdk.protocol.trade.trade_req_helper as trade_req
from rfsdk.comm_utils import parse_exchange_id, parse_broker_info, pb2json
from rfsdk.protocol.trade.trade_req_helper import InterfaceType


class BrokerType(object):
    SimNow = 'SimNow'
    SimTrade = 'SimTrade'


# 投机套保标识
class CombHedgeFlagType(object):
    HedgeFlag_Speculation = '0'  # 投机
    HedgeFlag_Arbitrage = '2'  # 套利
    HedgeFlag_Hedge = '3'  # 套保
    HedgeFlag_MarketMaker = '5'  # 做市商


# 开平仓
class CombOffsetFlagType(object):
    OffsetFlagType_Open = '0'  # 开仓
    OffsetFlagType_Close = '1'  # 平仓
    OffsetFlagType_ForceClose = '2'  # 强平
    OffsetFlagType_CloseToday = '3'  # 平今
    OffsetFlagType_CloseYesterday = '4'  # 平昨
    OffsetFlagType_ForceOff = '5'  # 强减
    OffsetFlagType_LocalForceClose = '6'  # 本地强平


class TradeClient(object):
    '''
    交易客户端
    '''

    def __init__(self, inter_service):
        self._investor_id = None
        self._investor_key = None
        self._rpc_call = None
        self._inter_service = None
        self._rpc_call_mf = None
        if isinstance(inter_service, Gateway):  # 暂时只支持网关接入
            self._inter_service = inter_service
            self._inter_service.set_protocol_head(chr(0x0f))
            self._rpc_call = self._inter_service.gateway_call
            self._rpc_call_mf = self._inter_service.gateway_call_mf
        else:
            raise Exception('not supported service type')

    def start(self):
        '''
        启动服务，连接网关
        '''
        return self._inter_service.connect()

    def wait(self):
        return self._inter_service.wait()

    def set_log_dir(self, is_console_log, log_dir=None):
        self._inter_service.set_log_dir(is_console_log, log_dir)

    def subscribe_trade(self, func):
        '''
        订阅成交回报
        Args:
            func:回调处理函数

        Returns:

        '''
        self._inter_service.get_client().register_cb(TOPIC_TRADE_FUTURES,
                                                     lambda pb_msg: pb2json(pb_msg, TradeReportInfo(), func))
        self._inter_service.get_client().subscribe(TOPIC_TRADE_FUTURES)

    def unsubscribe_trade(self):
        '''
        取消订阅成交回报
        '''
        self._inter_service.get_client().unsubscribe(TOPIC_TRADE_FUTURES)

    def subscribe_order(self, func):
        '''
        订阅委托回报
        '''
        self._inter_service.get_client().register_cb(TOPIC_ORDER_FUTURES,
                                                     lambda pb_msg: pb2json(pb_msg, OrderInfo(), func))
        self._inter_service.get_client().subscribe(TOPIC_ORDER_FUTURES)

    def unsubscribe_order(self):
        self._inter_service.get_client().unsubscribe(TOPIC_ORDER_FUTURES)
        self._inter_service.get_client().unregister_cb(TOPIC_ORDER_FUTURES)

    def login(self,
              investor_id,
              trade_password,
              broker_type,
              interface_type
              ):
        '''
        账户登入
        Args:
            investor_id: 账户/投资者id
            trade_password: 密码
            broker_type: 经纪商类型（目前支持模拟交易/SimNow）
            interface_type: 插件接口类型 枚举类型InterfaceType

        Returns:bool 是否登入成功

        '''
        trade_login_req = trade_req.make_login_req(investor_id=investor_id,
                                                   trade_password=trade_password,
                                                   op_station=None,
                                                   interface_type=interface_type,
                                                   account_type=trade_req.AccountType.AccountType_FUTURES,
                                                   source=trade_req.SourceType.SourceType_Trader,
                                                   broker_id=None,
                                                   user_product_info=None,
                                                   app_id=None,
                                                   auth_code=None,
                                                   collect_info=None,
                                                   flow_path=None,
                                                   client_public_ip=None,
                                                   client_port=None,
                                                   md_op_station=None,
                                                   client_id=None,
                                                   client_info=None,
                                                   is_auto_confirm=None,
                                                   is_sync_position=None,
                                                   is_check_pwd=None,
                                                   op_station_off=None)
        try:
            qsid, wtid = parse_broker_info(broker_type, interface_type)
        except Exception as e:
            ant.log_err(e)
            return False

        req = account_req.make_login_req(
            login=trade_login_req, qsid=qsid, wtid=wtid)

        ret, rsp = self._rpc_call(SERVICE_ACCOUNT, METHOD_ACCOUNT_LOGIN, req)

        if ret == 0:
            self._investor_key = rsp['login']['investor_key']
            self._investor_id = investor_id
            return True
        else:
            ant.log_err('login failed, err_code:%d, err_msg:%s', ret, rsp)
            return False

    def create_condition_service(self):
        return self._inter_service, self._investor_id, self._investor_key

    def logout(self):
        '''
        账号登出
        '''
        if self._investor_key is None:
            return -1, 'please login first!'

        account_logout_req = account_req.make_logout_req(
            investor_key=self._investor_key)
        return self._rpc_call(SERVICE_ACCOUNT, METHOD_ACCOUNT_LOGOUT, account_logout_req)

    def query_asset(self,
                    currency_id=None,
                    biz_type=None,
                    account_id=None,
                    client_id=None,
                    trading_day=None):
        '''
        查询资产
        Args:
            currency_id:货币代码： 1 人民币，2 美元 ，3 港币
            biz_type: 业务类型： 0为期货，1为股票
            account_id: 投资者账号
            client_id: 客户号（顶点）
            trading_day: 交易日

        Returns:QueryAsset Rsp

        '''
        req = trade_req.make_query_asset_req(investor_key=self._investor_key,
                                             currency_id=currency_id,
                                             biz_type=biz_type,
                                             account_id=account_id,
                                             client_id=client_id,
                                             trading_day=trading_day)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_ASSET, req)

    def query_order(self,
                    exchange_id=None,
                    instrument_id=None,
                    order_sys_id=None,
                    insert_time_start=None,
                    insert_time_end=None,
                    client_id=None):
        '''
        查询报单
        Args:
            instrument_id:合约代码
            exchange_id: 交易所代码
            order_sys_id: 报单编号
            insert_time_start: 开始时间
            insert_time_end: 结束时间
            client_id: 客户号（顶点）

        Returns:OrderInfo Rsp

        '''
        if exchange_id is None:
            if instrument_id is not None:
                exchange_id = parse_exchange_id(instrument_id)
            else:
                return -1, u'请填写交易所或合约代码'

        req = trade_req.make_query_order_req(investor_key=self._investor_key,
                                             instrument_id=instrument_id,
                                             exchange_id=exchange_id,
                                             order_sys_id=order_sys_id,
                                             insert_time_start=insert_time_start,
                                             insert_time_end=insert_time_end,
                                             client_id=client_id)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_ORDER, req)

    def query_trade(self, instrument_id, exchange_id=None, trade_id=None, trade_time_start=None, trade_time_end=None,
                    client_id=None, status=None):
        if exchange_id is None:
            if instrument_id is not None:
                exchange_id = parse_exchange_id(instrument_id)
            else:
                return -1, u'请填写交易所或合约代码'
        req = trade_req.make_query_report_req(investor_key=self._investor_key, instrument_id=instrument_id,
                                              exchange_id=exchange_id, trade_id=trade_id,
                                              trade_time_start=trade_time_start, trade_time_end=trade_time_end,
                                              client_id=client_id, status=status)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_ORDER_QUERY_TRADE, req)

    def query_position_detail(self,
                              instrument_id=None,
                              exchange_id=None,
                              historical_date=None,
                              type=None):
        '''
        查询持仓明细（模拟期货）
        Args:
            instrument_id: 合约代码
            exchange_id: 交易所代码
            historical_date: 历史持仓日期
            type: 接口类型 0未定义 1 查询持仓明细标志 2 查询持仓汇总标志

        Returns:QueryPositionDetail Rsp

        '''
        req = trade_req.make_query_position_detail_req(investor_key=self._investor_key,
                                                       instrument_id=instrument_id,
                                                       exchange_id=exchange_id,
                                                       historical_date=historical_date,
                                                       type=type)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_POSITION_DETAIL, req)

    def query_position(self,
                       instrument_id=None,
                       exchange_id=None,
                       historical_date=None,
                       client_id=None):
        '''
        查持仓
        Args:
            instrument_id:合约
            exchange_id:交易所
            historical_date:历史日期
            client_id:顶点
        '''
        exchange_id = parse_exchange_id(instrument_id)
        req = trade_req.make_query_position_req(investor_key=self._investor_key,
                                                instrument_id=instrument_id,
                                                exchange_id=exchange_id,
                                                historical_date=historical_date,
                                                client_id=client_id)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_POSITION, req)

    def order_insert(self,
                     instrument_id,
                     direction,
                     comb_offset_flag,
                     volume_total_original,
                     order_no=None,
                     order_price_type=trade_req.OrderPriceType.OrderPriceType_LimitPrice,
                     limit_price=None,  # 根据order_price_type类型填写
                     comb_hedge_flag=CombHedgeFlagType.HedgeFlag_Speculation,  # 投机
                     time_condition=trade_req.TimeConditionType.TimeConditionType_GFD,
                     gtd_date=None,
                     volume_condition=None,
                     min_volume=None,
                     contingent_condition=None,
                     stop_price=None,
                     force_close_reason=None,
                     user_force_close=None,
                     is_swap_order=None,
                     local_order_no=None,
                     client_id=None,
                     source=None,
                     is_back_hand=None,
                     is_change_order=None,
                     new_order_price_type=None,
                     new_limit_price=None,
                     price_tick_num=None,
                     exchange_id=None):
        '''
        报单
        Args:
            instrument_id: 合约代码
            direction: 买卖方向：枚举ActionType（1买入，2卖出，3认购，4申购，5赎回）
            comb_offset_flag: 开平标志： 枚举类型OffsetFlagType0开仓（1平仓，2强平，3平今，4平昨，5强减，6本地强平）
            comb_hedge_flag: 投机套保标志：枚举类型HedgeFlagType（0投机，2套利，3套保，5做市商 ）
             volume_total_original: 数量
            order_price_type:报单价格条件
            limit_price: 价格
            order_no: 报单申报编号
            time_condition: 有效期类型
            gtd_date: GTD日期
            volume_condition: 成交类型
            min_volume: 最小成交量
            contingent_condition:条件类型
            stop_price: 止损价
            force_close_reason:强平原因
            user_force_close: 强平标志
            is_swap_order: 互换单标志
            local_order_no: 报单自定义编号（ctp）
            client_id: 顶点
            source: 来源：0默认SDK网关，1交易模块，2条件单模块，3http网关入口
            is_back_hand: 反手标志
            is_change_order: 改单标志
            new_order_price_type: 新报单价格条件
            new_limit_price: 新价格
            price_tick_num: 价差数量

        Returns:OrderInsert Rsp

        '''
        if exchange_id is None:
            if instrument_id is not None:
                exchange_id = parse_exchange_id(instrument_id)
            else:
                return -1, u'请填写交易所或合约代码'
        if order_price_type is trade_req.OrderPriceType.OrderPriceType_LimitPrice and limit_price is None:
            return -1, u'价格类型为限价，请填写价格'

        req = trade_req.make_order_insert_req(investor_key=self._investor_key,
                                              instrument_id=instrument_id,
                                              order_no=order_no,
                                              order_price_type=order_price_type,
                                              direction=direction,
                                              comb_offset_flag=comb_offset_flag,
                                              comb_hedge_flag=comb_hedge_flag,
                                              limit_price=limit_price,
                                              volume_total_original=volume_total_original,
                                              time_condition=time_condition,
                                              gtd_date=gtd_date,
                                              volume_condition=volume_condition,
                                              min_volume=min_volume,
                                              contingent_condition=contingent_condition,
                                              stop_price=stop_price,
                                              force_close_reason=force_close_reason,
                                              user_force_close=user_force_close,
                                              is_swap_order=is_swap_order,
                                              exchange_id=exchange_id,
                                              local_order_no=local_order_no,
                                              client_id=client_id,
                                              source=source,
                                              is_back_hand=is_back_hand,
                                              is_change_order=is_change_order,
                                              new_order_price_type=new_order_price_type,
                                              new_limit_price=new_limit_price,
                                              price_tick_num=price_tick_num)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_INSERT_ORDER, req)

    def order_cancel(self,
                     order_no,
                     order_sys_id=None,
                     exchange_id=None,
                     cancel_order_no=None,
                     instrument_id=None,
                     client_id=None,
                     is_change_order=None,
                     volume_total_original=None,
                     order_price_type=None,
                     limit_price=None,
                     price_tick_num=None):
        '''
         撤销报单
        Args:
            order_no: 报单申请编号
            cancel_order_no: 报单操作
            order_sys_id: 报单编号
            instrument_id: 合约代码
            investor_id: 投资者id
            client_id: 顶点
            is_change_order:改单标志
            volume_total_original: 改单数量
            order_price_type: 改单报单价格条件
            limit_price: 新价格
            price_tick_num: 价差数量

        Returns:OrderCancel Rsp

        '''
        if exchange_id is None:
            if instrument_id is not None:
                exchange_id = parse_exchange_id(instrument_id)
            else:
                return -1, u'请填写交易所或合约代码'
        req = trade_req.make_order_cancel_req(investor_key=self._investor_key,
                                              cancel_order_no=cancel_order_no,
                                              order_no=order_no,
                                              exchange_id=exchange_id,
                                              order_sys_id=order_sys_id,
                                              instrument_id=instrument_id,
                                              investor_id=self._investor_id,
                                              client_id=client_id,
                                              is_change_order=is_change_order,
                                              volume_total_original=volume_total_original,
                                              order_price_type=order_price_type,
                                              limit_price=limit_price,
                                              price_tick_num=price_tick_num)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_CANCEL_ORDER, req)

    def query_instrument(self, instrument_id, exchange_id=None):
        '''
        查询合约
        Args:
            instrument_id:合约代码

        Returns:QueryInstrumentRsp

        '''
        if exchange_id is None:
            if instrument_id is not None:
                exchange_id = parse_exchange_id(instrument_id)
            else:
                return -1, u'请填写交易所或合约代码'
        req = trade_req.make_query_instrument_req(investor_key=self._investor_key,
                                                  exchange_id=exchange_id,
                                                  instrument_id=instrument_id)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_INSTRUMENT, req)

    def query_margin_rate(self,
                          instrument_id,
                          hedge_flag=trade_req.HedgeFlagType.HedgeFlag_Speculation,
                          exchange_id=None):
        '''
        查询保证金率
        Args:
            instrument_id: 合约
            hedge_flag:投机套保标志
            exchange_id:交易所代码

        Returns: QueryMarginRate Rsp

        '''
        if exchange_id is None:
            if instrument_id is not None:
                exchange_id = parse_exchange_id(instrument_id)
            else:
                return -1, u'请填写交易所或合约代码'
        req = trade_req.make_query_margin_rate_req(investor_key=self._investor_key,
                                                   instrument_id=instrument_id,
                                                   hedge_flag=hedge_flag,
                                                   exchange_id=exchange_id)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_MARGIN_RATE, req)

    def query_commission_rate(self,
                              instrument_id,
                              exchange_id=None):
        '''
        查询手续费率
        Args:
            instrument_id: 合约代码
            exchange_id: 交易所代码

        Returns:QueryCommissionRate Rsp

        '''
        if exchange_id is None:
            if instrument_id is not None:
                exchange_id = parse_exchange_id(instrument_id)
            else:
                return -1, u'请填写交易所或合约代码'
        req = trade_req.make_query_commission_rate_req(investor_key=self._investor_key,
                                                       instrument_id=instrument_id,
                                                       exchange_id=exchange_id)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_ORDER_QUERY_COMMISSION_RATE, req)

    def query_max_order_volume(self,
                               instrument_id,
                               direction,
                               exchange_id=None,
                               limit_price=None,
                               offset_flag=None,
                               hedge_flag=None,
                               max_volume=None,
                               investor_unit_id=None
                               ):
        '''
        查询最大保单数量
        Args:
            instrument_id: 合约代码
            exchange_id: 交易所代码
            direction: 买卖方向
            offset_flag: 开平标志
            max_volume: 最带允许报单数量
            investor_unit_id: 投资单元代码
            limit_price: 价格

        Returns:QueryMaxOrderVolume Rsp

        '''
        if exchange_id is None:
            if instrument_id is not None:
                exchange_id = parse_exchange_id(instrument_id)
            else:
                return -1, u'请填写交易所或合约代码'
        req = trade_req.make_query_max_order_volume_req(investor_key=self._investor_key,
                                                        instrument_id=instrument_id,
                                                        exchange_id=exchange_id,
                                                        direction=direction,
                                                        hedge_flag=hedge_flag,
                                                        offset_flag=offset_flag,
                                                        max_volume=max_volume,
                                                        investor_unit_id=investor_unit_id,
                                                        limit_price=limit_price)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_MAX_ORDER_VOLUME, req)

    def query_trading_code(self,
                           exchange_id=None,
                           broker_id=None,
                           client_id=None,
                           is_active=None,
                           client_id_type=None,
                           investor_unit_id=None):
        '''
        查询交易编码
        Args:
            exchange_id: 交易所代码
            client_id: 经纪商id
            is_active: 是否活跃
            client_id_type:交易编码类型 1投机 2套利 3套保 5做市商
            investor_unit_id: 投资单元代码

        Returns:QryTradingCode Rsp

        '''
        req = trade_req.make_qry_trading_code_req(investor_key=self._investor_key,
                                                  exchange_id=exchange_id,
                                                  broker_id=broker_id,
                                                  client_id=client_id,
                                                  is_active=is_active,
                                                  client_id_type=client_id_type,
                                                  investor_unit_id=investor_unit_id)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_TRADING_CODE, req)

    def query_investor(self,
                       broker_id):
        '''
        查询投资者
        Args:
            broker_id: 经纪商id
            investor_id: 投资者id

        Returns:QueryInvestor Rsp

        '''
        req = trade_req.make_query_investor_req(investor_key=self._investor_key,
                                                broker_id=broker_id,
                                                investor_id=self._investor_id)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_INVESTOR, req)

    def confirm_settlement_info(self,
                                broker_id,
                                trading_day=None,
                                account_id=None,
                                currency_id=None):
        '''
        投资者结算结果确认
        Args:
            broker_id: 经纪商id
            investor_id: 投资者id
            trading_day: 交易日
            account_id: 投资者账号
            currency_id: 货币代码 1人民币 2美元 3港币

        Returns:ConfirmSettlementInfo Rsp

        '''
        req = trade_req.make_confirm_settlement_info_req(investor_key=self._investor_key,
                                                         broker_id=broker_id,
                                                         investor_id=self._investor_id,
                                                         trading_day=trading_day,
                                                         account_id=account_id,
                                                         currency_id=currency_id)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_CONFIRM_SETTLEMENT_INFO, req)

    def query_settlement_info(self,
                              broker_id,
                              trading_day,
                              account_id=None,
                              currency_id=None,
                              start_date=None,
                              end_date=None
                              ):
        '''
        查询投资者结算结果
        Args:
            broker_id: 经纪商id
            investor_id: 投资者id
            trading_day: 交易日 "yyyymmdd"日，“yyyymm” 月
            account_id: 投资者账号
            currency_id: 货币代码 1人民币 2美元 3港币

        Returns:QuerySettlementInfo Rsp

        '''
        req = trade_req.make_query_settlement_info_req(investor_key=self._investor_key,
                                                       broker_id=broker_id,
                                                       investor_id=self._investor_id,
                                                       trading_day=trading_day,
                                                       account_id=account_id,
                                                       currency_id=currency_id, start_date=start_date,
                                                       end_date=end_date)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_SETTLEMENT_INFO, req)

    def query_settlement_info_confirm(self,
                                      broker_id,
                                      account_id=None,
                                      currency_id=None
                                      ):
        '''
        查询投资者结算结果
        Args:
            broker_id: 经纪商id
            investor_id: 投资者id
            account_id: 投资者账号
            currency_id: 货币代码 1人民币 2美元 3港币

        Returns:QuerySettlementInfoConfirm Rsp

        '''
        req = trade_req.make_query_settlement_info_confirm_req(investor_key=self._investor_key,
                                                               broker_id=broker_id,
                                                               investor_id=self._investor_id,
                                                               account_id=account_id,
                                                               currency_id=currency_id
                                                               )
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_SETTLEMENT_INFO_CONFIRM, req)

    def user_password_update(self,
                             old_password,
                             new_password
                             ):
        '''
        修改密码
        Args:
            old_password:旧密码
            new_password:新密码

        Returns:UserPassWordUpdate Rsp

        '''
        req = trade_req.make_user_password_update_req(investor_key=self._investor_key,
                                                      old_password=old_password,
                                                      new_password=new_password)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_USER_PASSWORD_UPDATE, req)

    def query_bank_account_money(self,
                                 bank_id,
                                 bank_branch_id,
                                 bank_password,
                                 password,
                                 currency_id,
                                 broker_branch_id,
                                 account,
                                 bank_account):
        req = trade_req.make_query_bank_account_money_req(investor_key=self._investor_key,
                                                          bank_id=bank_id,
                                                          bank_branch_id=bank_branch_id,
                                                          bank_password=bank_password,
                                                          password=password,
                                                          currency_id=currency_id,
                                                          broker_branch_id=broker_branch_id,
                                                          account=account,
                                                          bank_account=bank_account)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_BANK_ACCOUNT_MONEY, req)

    def from_bank_to_future(self, bank_id, currency_id, bank_branch_id, password, bank_password, trade_amount,
                            bank_account, account, broker_branch_id=None):
        req = trade_req.make_from_bank_to_future_req(investor_key=self._investor_key, bank_id=bank_id,
                                                     currency_id=currency_id, bank_branch_id=bank_branch_id,
                                                     password=password, bank_password=bank_password,
                                                     account=account,
                                                     trade_amount=trade_amount, bank_account=bank_account,
                                                     broker_branch_id=broker_branch_id)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_FROM_BANK_TO_FUTURE, req)

    def from_future_to_bank(self, bank_id, currency_id, bank_branch_id, password, bank_password, trade_amount, account,
                            transfer_direction,
                            bank_account, broker_branch_id=None):
        req = trade_req.make_from_future_to_bank_req(investor_key=self._investor_key, bank_id=bank_id,
                                                     currency_id=currency_id, bank_branch_id=bank_branch_id,
                                                     password=password, bank_password=bank_password,
                                                     trade_amount=trade_amount, account=account,
                                                     transfer_direction=transfer_direction,
                                                     bank_account=bank_account, broker_branch_id=broker_branch_id)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_FROM_FUTURE_TO_BANK, req)

    def query_contract_bank(self):
        req = trade_req.make_query_contract_bank_req(investor_key=self._investor_key)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_CONTRACT_BANK, req)

    def query_account_register(self, currency_id=None):
        req = trade_req.make_query_accountregister_req(investor_key=self._investor_key, currency_id=currency_id)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_ACCOUNT_REGISTER, req)

    def query_transfer_serial(self, bank_id=None, currency_id=None, start_date=None, end_date=None):
        req = trade_req.make_query_transfer_serial_req(investor_key=self._investor_key, bank_id=bank_id,
                                                       currency_id=currency_id, start_date=start_date,
                                                       end_date=end_date)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_TRANSFER_SERIAL, req)

    def query_trading_notice(self, investor_unit_id):
        req = trade_req.make_query_trading_notice_req(investor_key=self._investor_key,
                                                      investor_unit_id=investor_unit_id)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_TRADING_NOTICE, req)

    def make_query_notice(self):
        req = trade_req.make_query_notice_req(investor_key=self._investor_key)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_NOTICE, req)

    def trading_account_password_update(self, old_password, new_password, currency_id):
        req = trade_req.make_trading_account_password_update_req(investor_key=self._investor_key,
                                                                 old_password=old_password, new_password=new_password,
                                                                 currency_id=currency_id)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_TRADING_ACCOUNT_PASSWORD_UPDATE, req)

    def query_cfmmc_account_token(self, broker_id=None, investor_unit_id=None, investor_id=None):
        req = trade_req.make_query_CFMMC_trading_account_token_req(investor_key=self._investor_key, broker_id=broker_id,
                                                                   investor_unit_id=investor_unit_id,
                                                                   investor_id=investor_id)
        return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_CFMMC_ACCOUNT_TOKEN, req)
